@@ -133,11 +133,7 @@ gedit_preferences_dialog_dispose (GObject *object)
 {
 	GeditPreferencesDialog *dlg = GEDIT_PREFERENCES_DIALOG (object);
 
-	if (dlg->priv->editor != NULL)
-	{
-		g_object_unref (dlg->priv->editor);
-		dlg->priv->editor = NULL;
-	}
+	g_clear_object (&dlg->priv->editor);
 
 	G_OBJECT_CLASS (gedit_preferences_dialog_parent_class)->dispose (object);
 }
@@ -486,21 +482,25 @@ style_scheme_changed (GtkWidget              *treeview,
 		      GeditPreferencesDialog *dlg)
 {
 	GtkTreePath *path;
-	GtkTreeIter iter;
-	gchar *id;
 
 	gtk_tree_view_get_cursor (GTK_TREE_VIEW (dlg->priv->schemes_treeview), &path, NULL);
-	gtk_tree_model_get_iter (GTK_TREE_MODEL (dlg->priv->schemes_treeview_model),
-				 &iter, path);
-	gtk_tree_path_free (path);
-	gtk_tree_model_get (GTK_TREE_MODEL (dlg->priv->schemes_treeview_model),
-			    &iter, ID_COLUMN, &id, -1);
+	if (path != NULL)
+	{
+		GtkTreeIter iter;
+		gchar *id;
 
-	g_settings_set_string (dlg->priv->editor, GEDIT_SETTINGS_SCHEME, id);
+		gtk_tree_model_get_iter (GTK_TREE_MODEL (dlg->priv->schemes_treeview_model),
+					 &iter, path);
+		gtk_tree_path_free (path);
+		gtk_tree_model_get (GTK_TREE_MODEL (dlg->priv->schemes_treeview_model),
+				    &iter, ID_COLUMN, &id, -1);
 
-	set_buttons_sensisitivity_according_to_scheme (dlg, id);
+		g_settings_set_string (dlg->priv->editor, GEDIT_SETTINGS_SCHEME, id);
 
-	g_free (id);
+		set_buttons_sensisitivity_according_to_scheme (dlg, id);
+
+		g_free (id);
+	}
 }
 
 static const gchar *
