@@ -111,25 +111,12 @@ gedit_app_dispose (GObject *object)
 {
 	GeditApp *app = GEDIT_APP (object);
 
-	if (app->priv->window_settings != NULL)
-	{
-		g_object_unref (app->priv->window_settings);
-		app->priv->window_settings = NULL;
-	}
+	g_clear_object (&app->priv->window_settings);
+	g_clear_object (&app->priv->settings);
 
-	if (app->priv->settings != NULL)
-	{
-		g_object_unref (app->priv->settings);
-		app->priv->settings = NULL;
-	}
-
-	if (app->priv->extensions != NULL)
-	{
-		/* Note that unreffing the extensions will automatically remove
-		   all extensions which in turn will deactivate the extension */
-		g_object_unref (app->priv->extensions);
-		app->priv->extensions = NULL;
-	}
+	/* Note that unreffing the extensions will automatically remove
+	   all extensions which in turn will deactivate the extension */
+	g_clear_object (&app->priv->extensions);
 
 	G_OBJECT_CLASS (gedit_app_parent_class)->dispose (object);
 }
@@ -494,7 +481,7 @@ extension_added (PeasExtensionSet *extensions,
 		 PeasExtension    *exten,
 		 GeditApp         *app)
 {
-	peas_extension_call (exten, "activate");
+	gedit_app_activatable_activate (GEDIT_APP_ACTIVATABLE (exten));
 }
 
 static void
@@ -503,7 +490,7 @@ extension_removed (PeasExtensionSet *extensions,
 		   PeasExtension    *exten,
 		   GeditApp         *app)
 {
-	peas_extension_call (exten, "deactivate");
+	gedit_app_activatable_deactivate (GEDIT_APP_ACTIVATABLE (exten));
 }
 
 static void
@@ -535,7 +522,9 @@ gedit_app_init (GeditApp *app)
 			  G_CALLBACK (extension_removed),
 			  app);
 
-	peas_extension_set_call (app->priv->extensions, "activate");
+	peas_extension_set_foreach (app->priv->extensions,
+	                            (PeasExtensionSetForeachFunc) extension_added,
+	                            app);
 }
 
 /**
