@@ -702,11 +702,7 @@ gedit_documents_panel_dispose (GObject *object)
 		panel->priv->refresh_idle_id = 0;
 	}
 
-	if (panel->priv->window != NULL)
-	{
-		g_object_unref (panel->priv->window);
-		panel->priv->window = NULL;
-	}
+	g_clear_object (&panel->priv->window);
 
 	G_OBJECT_CLASS (gedit_documents_panel_parent_class)->dispose (object);
 }
@@ -1094,6 +1090,7 @@ gedit_documents_panel_init (GeditDocumentsPanel *panel)
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell;
 	GtkTreeSelection *selection;
+	GIcon *icon;
 
 	gedit_debug (DEBUG_PANEL);
 
@@ -1161,7 +1158,10 @@ gedit_documents_panel_init (GeditDocumentsPanel *panel)
 				     column);
 
 	cell = gedit_cell_renderer_button_new ();
-	g_object_set (cell, "stock-id", GTK_STOCK_CLOSE, NULL);
+
+	icon = g_themed_icon_new_with_default_fallbacks ("window-close-symbolic");
+	g_object_set (cell, "gicon", icon, NULL);
+	g_object_unref (icon);
 	gtk_tree_view_column_pack_end (column, cell, FALSE);
 	g_signal_connect (cell,
 	                  "clicked",
