@@ -205,10 +205,11 @@ gedit_multi_notebook_class_init (GeditMultiNotebookClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (GeditMultiNotebookClass, show_popup_menu),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__BOXED,
+			      gedit_marshal_VOID__BOXED_OBJECT,
 			      G_TYPE_NONE,
-			      1,
-			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
+			      2,
+			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE,
+			      GEDIT_TYPE_TAB);
 
 	g_object_class_install_property (object_class,
 					 PROP_ACTIVE_NOTEBOOK,
@@ -228,18 +229,13 @@ gedit_multi_notebook_class_init (GeditMultiNotebookClass *klass)
 							      G_PARAM_STATIC_STRINGS));
 }
 
-static gboolean
-notebook_button_press_event (GtkNotebook        *notebook,
-			     GdkEventButton     *event,
-			     GeditMultiNotebook *mnb)
+static void
+notebook_show_popup_menu (GtkNotebook        *notebook,
+                          GdkEvent           *event,
+                          GeditTab           *tab,
+                          GeditMultiNotebook *mnb)
 {
-	if (GDK_BUTTON_PRESS == event->type && 3 == event->button)
-	{
-		g_signal_emit (G_OBJECT (mnb), signals[SHOW_POPUP_MENU], 0,
-		               event);
-	}
-
-	return FALSE;
+	g_signal_emit (G_OBJECT (mnb), signals[SHOW_POPUP_MENU], 0, event, tab);
 }
 
 static void 
@@ -410,8 +406,8 @@ connect_notebook_signals (GeditMultiNotebook *mnb,
 			  G_CALLBACK (notebook_tab_close_request),
 			  mnb);
 	g_signal_connect (notebook,
-			  "button-press-event",
-			  G_CALLBACK (notebook_button_press_event),
+			  "show-popup-menu",
+			  G_CALLBACK (notebook_show_popup_menu),
 			  mnb);
 }
 
@@ -433,7 +429,7 @@ disconnect_notebook_signals (GeditMultiNotebook *mnb,
 					      mnb);
 	g_signal_handlers_disconnect_by_func (notebook, notebook_tab_close_request,
 					      mnb);
-	g_signal_handlers_disconnect_by_func (notebook, notebook_button_press_event,
+	g_signal_handlers_disconnect_by_func (notebook, notebook_show_popup_menu,
 					      mnb);
 }
 
