@@ -151,17 +151,8 @@ gedit_spell_plugin_dispose (GObject *object)
 
 	gedit_debug_message (DEBUG_PLUGINS, "GeditSpellPlugin disposing");
 
-	if (plugin->priv->action_group != NULL)
-	{
-		g_object_unref (plugin->priv->action_group);
-		plugin->priv->action_group = NULL;
-	}
-
-	if (plugin->priv->window != NULL)
-	{
-		g_object_unref (plugin->priv->window);
-		plugin->priv->window = NULL;
-	}
+	g_clear_object (&plugin->priv->action_group);
+	g_clear_object (&plugin->priv->window);
 
 	G_OBJECT_CLASS (gedit_spell_plugin_parent_class)->dispose (object);
 }
